# CEPC Matplotlib Style

**Link**: https://code.ihep.ac.cn/zhangyang98/cepc-style
**Author**: Yang Zhang  
**Email**: zhangyang98@ihep.ac.cn  
**Institution**: Institute of High Energy Physics, Chinese Academy of Science  
**Version**: 0.0.1  
**Date**: 2025-05-30  


![Example Plot](./sample_figures/example_plot.png)  
![Example Plot](./sample_figures/example_hist.png)  
![Example Plot](./sample_figures/example_hist2d.png)  
*Reference plotting style for CEPC*


## Quick start
1. Place `cepc_style.mplstyle` in your project
2. In your Python script:
```python
import matplotlib.pyplot as plt

# Apply style BEFORE creating figures
plt.style.use('path/to/cepc_style.mplstyle')

# Create plot with styled defaults
fig, ax = plt.subplots(figsize=(10,6))
ax.plot([1,2,3], [4,5,6], linewidth=3)
ax.set_xlabel("Energy [GeV]")
plt.savefig("plot.pdf")
plt.show()
```

For more personalized settings, please refer to [Examples](examples)

## Examples
We provide complete plotting examples in `examples.py` demonstrating:

### 1. Line plots
  ```python
  def example_draw_plot():
    # Creates sin/cos curves with:
    - Custom line widths (3pt)
    - CEPC Ref-TDR annotation (top-left)
    - Luminosity/energy info (top-right)
    - Vector PDF output
  ```
### 2. Histograms
  ```python
  def example_draw_hist():
    # Demonstrates:
    - Step-style histograms
    - Proper axis labeling
    - Standard CEPC text annotations
    - Multi-dataset handling
  ```

### 3. 2D Histogram
  ```python
  def example_draw_hist2d():
    # Shows:
    - Color-mapped 2D distributions
    - Color bar integration
    - Range/binning control
    - Publication-ready styling
  ```


Run all examples with:
```bash
python examples.py
```